==> git-pm-1.0.0.tar.gz: git-pm-1.0.0/git_pm/lib/parser.py <==
#!/usr/bin/python3
# -*- coding: utf-8 -*-

##imports
#stdlib
import argparse
import configparser
import os
import sys
import getpass
#self
from lib.tools import deep_convert_dict, Logger
from lib.text import *
from core import __version__, __version_name__

#Parser overcharge
class ColoredParser(argparse.ArgumentParser):

    def error (self, message):
        """error(message: string)

        Prints a usage message incorporating the message to stderr and
        exits.

        If you override this in a subclass, it should not return -- it
        should either exit or raise an exception.
        """
        self.print_usage(sys.stderr)
        args = {'prog': self.prog, 'message': bold(red(message))}
        self.exit(2, ('%(prog)s: error: %(message)s\n' % args))

def confparse(args = None):
    """parses the config file or creates one if none is to be found"""
    config = configparser.ConfigParser()

    conf_dir_path = os.path.join( os.path.dirname(__file__), os.pardir, 'conf')
    conf_file_path = os.path.join( conf_dir_path, 'git-pm.ini' )
    try:
        if not os.path.isdir(conf_dir_path) and 'flush' not in args:
            os.mkdir(conf_dir_path)
            os.chmod(conf_dir_path, 0o775)
    except PermissionError:
        pass

    if not os.path.isfile(conf_file_path):
        config['dir'] = {'temp': '/tmp/git-pm',
                         'inst': '/opt/git-pm'}
        config['log'] = {'alwayslog': 'yes',
                         'path': '/var/log/git-pm.log'}
        config['setup'] = {'defaultstate':'rolling'}
        config['info'] = {'version': __version__+'/'+__version_name__}

        if not 'flush' in args: #do not create a new conf file as we try to delete it !
            try:
                with open(conf_file_path, 'w') as conf_file:
                    config.write(conf_file)
                os.chmod(conf_file_path, 0o666)
            except (PermissionError, FileNotFoundError):
                pass

    try:
        config.read(conf_file_path)
    except FileNotFoundError:
        pass
    options = {'config':conf_file_path}
    options.update(deep_convert_dict(config._sections))
    return options



# MAIN PARSER
def parse(args=None):
    """
    Parses the given arguments and the config files and returns the options
    dictionnary.

    keyword arguments:
        args - a list containing arguments passed to the command (default=None)
    """
    ##argparse
    parser = ColoredParser(description='The Git Package Manager')
    command_subparsers = parser.add_subparsers(dest='cmd', metavar='cmd')
    #command_subparsers.required = True
    parser_verbose = parser.add_mutually_exclusive_group()
    parser_verbose.add_argument("-v", "--verbose", action="store_true", default=False, help="increase output verbosity")
    parser_verbose.add_argument('-q', '--quiet', action='store_true', default=False, help='do not write any output')
    #list
    list_parser=command_subparsers.add_parser('list', help='lists installed packages', prefix_chars='-+/')
    #list::output
    list_output = list_parser.add_mutually_exclusive_group()
    list_output.add_argument("-p", "--pipe", action="store_true", help='output a list of package in a format that can be piped')
    list_output.add_argument('-i', '--infos', action='store', nargs="+", help='infos to print in output among ',
                              choices=['name', 'author', 'installed', 'latest', 'state', 'url', 'install_type'],
                              default = ['name', 'author', 'installed', 'latest', 'state'])
    #list::state
    list_state = list_parser.add_mutually_exclusive_group()
    list_state.add_argument('-f', '--frozen', action='store_true', default=None, help='list frozen packages')
    list_state.add_argument('-r', '--rolling', action='store_true', default=None, help='list rolling packages')
    #list::uptodate
    list_uptodate = list_parser.add_mutually_exclusive_group()
    list_uptodate.add_argument('-u', '--uptodate', action="store_false", default=None, help='list non up-to-date packages')
    list_uptodate.add_argument('+u', '++uptodate', action="store_true", default=None, help='list up-to-date packages')
    #list::other
    list_parser.add_argument('-a', '--author', action='store', nargs=1, dest='author', default=None, help='list packages of author')

    #update
    update_parser=command_subparsers.add_parser('update', help='get the latest commited version of installed packages')
    #upgrade
    upgrade_parser=command_subparsers.add_parser('upgrade', help='upgrades the packages which are not up-to-date (providing they are not frozen)')
    upgrade_parser.add_argument('packages', metavar='repo', type=str, nargs='*', default=None, help='upgrade only selected packages')
    upgrade_parser.add_argument('-a', '--author', action='store', nargs=1, dest='author', default=None, help='upgrade packages of author')
    #freeze
    frozen_parser=command_subparsers.add_parser('freeze', help='prevents a package from being upgraded')
    frozen_parser.add_argument('packages', metavar='repo', type=str, nargs='*', default=None, help='package to freeze')
    frozen_parser.add_argument('-r','--rolling', action='store_true', default=None, help='freeze all rolling packages')
    frozen_parser.add_argument('-a','--author', action='store', nargs=1, dest='author', default=None, help='freeze packages of author')
    #roll
    rolling_parser=command_subparsers.add_parser('roll', help='allows a package to be upgraded again')
    rolling_parser.add_argument('packages', metavar='repo', type=str, nargs='*', default=None, help='package to roll')
    rolling_parser.add_argument('-f','--frozen', action='store_true', default=None, help='roll every frozen packages')
    rolling_parser.add_argument('-a','--author', action='store', nargs=1, dest='author', default=None, help='roll packages of author')
    #install
    install_parser=command_subparsers.add_parser('install', help='install selected package')
    install_parser.add_argument('packages', metavar='repo', type=str, nargs='+', help='package to install')
    install_parser.add_argument('--standalone', action='store_true', default=False, help='install all packages as standalone')
    #uninstall
    uninstall_parser=command_subparsers.add_parser('uninstall', help='uninstall selected package')
    uninstall_parser.add_argument('packages', metavar='repo', type=str, nargs='*', default=None, help='package to uninstall')
    uninstall_parser.add_argument('-a','--author', action='store', nargs=1, dest='author', default=None, help='uninstall packages of author')
    #info
    info_parser=command_subparsers.add_parser('info', help='grab infos about git-pm')
    info_parser.add_argument('-r', '--release', '--version', action='store_true', dest='release', default=False, help='print release version')
    info_parser.add_argument('-w', '--whereis', action='store_true', default=False, help='print localisation of script and config files')
    info_parser.add_argument('--poetry', action='store_true', default=[])
    #flush
    flush_parser=command_subparsers.add_parser('flush', help='deletes all files installed by git-pm (database, config files, logs, installed repositories, temporary directories)')

    options = vars(parser.parse_args(args))

    #add parsers to options dict for further referencement
    options['parser'] = {'main':parser, 'list':list_parser, 'upgrade':upgrade_parser,
                         'update':update_parser, 'freeze':frozen_parser,
                         'install':install_parser, 'roll':rolling_parser,
                         'uninstall':uninstall_parser, 'info':info_parser,
                         'flush':flush_parser}

    options.update(deep_convert_dict(confparse(args)))

    ##corrects dict
    ##Dicts may have missing entries depending on the command that was used
    for option in ('frozen', 'rolling', 'author', 'uptodate', 'release', 'whereis'):
        if not option in options.keys(): options[option]=None
    #package default does not work well
    if not 'packages' in options.keys() or not options['packages']: options['packages']=None
    #if no info option is passed: print all infos
    if options['cmd'] == 'info' and (True not in (options['release'], options['whereis'], options['poetry'])):
        options['whereis'], options['release'] = True, True
    ##checks for errors:
    if options['cmd'] is None:
        parser.print_help()
        parser.exit(2)
    #sudo ?
    if options['cmd']:
        if getpass.getuser() != 'root' and options['cmd'] not in ('info', 'list'):
            options['parser'][options['cmd']].error(red(bold('git-pm {} must be executed as root'.format(options['cmd']))))
    if not options['cmd'] in ('list', 'update', 'upgrade', 'info', 'flush'):
        if options['frozen'] is None and options['rolling'] is None and options['packages'] is None and options['author'] is None:
            options['parser'][options['cmd']].error('need packages to work on')

    return options

==> git-pm-1.1.5.tar.gz: git-pm-1.1.5/git_pm/lib/parser.py <==
#!/usr/bin/python3
# -*- coding: utf-8 -*-

##imports
#stdlib
import argparse
import configparser
import os
import sys
import getpass
#self
from lib.tools import deep_convert_dict, Logger
from lib.text import *
from core import __version__, __version_name__

#Parser overcharge
class ColoredParser(argparse.ArgumentParser):

    def error (self, message):
        """error(message: string)

        Prints a usage message incorporating the message to stderr and
        exits.

        If you override this in a subclass, it should not return -- it
        should either exit or raise an exception.
        """
        self.print_usage(sys.stderr)
        args = {'prog': self.prog, 'message': bold(red(message))}
        self.exit(2, ('%(prog)s: error: %(message)s\n' % args))

def confparse(args = None):
    """parses the config file or creates one if none is to be found"""
    config = configparser.ConfigParser()

    conf_dir_path = os.path.join('/var/lib/git-pm')
    conf_file_path = os.path.join( conf_dir_path, 'git-pm.ini' )
    try:
        if not os.path.isdir(conf_dir_path) and 'flush' not in args:
            os.mkdir(conf_dir_path)
            os.chmod(conf_dir_path, 0o775)
    except PermissionError:
        pass

    if not os.path.isfile(conf_file_path):
        config['dir'] = {'temp': '/tmp/git-pm',
                         'inst': '/opt/git-pm'}
        config['log'] = {'alwayslog': 'yes',
                         'path': '/var/log/git-pm.log'}
        config['setup'] = {'defaultstate':'rolling'}
        config['info'] = {'version': __version__+'/'+__version_name__}

        if not 'flush' in args and not 'info' in args: #do not create a new conf file as we try to delete it !
            try:
                with open(conf_file_path, 'w') as conf_file:
                    config.write(conf_file)
                os.chmod(conf_file_path, 0o666)
            except (PermissionError, FileNotFoundError):
                pass

    try:
        config.read(conf_file_path)
    except FileNotFoundError:
        pass
    options = {'config':conf_file_path}
    options.update(deep_convert_dict(config._sections))
    return options



# MAIN PARSER
def parse(args=None):
    """
    Parses the given arguments and the config files and returns the options
    dictionnary.

    keyword arguments:
        args - a list containing arguments passed to the command (default=None)
    """
    ##argparse
    parser = ColoredParser(description='The Git Package Manager')
    command_subparsers = parser.add_subparsers(dest='cmd', metavar='cmd')
    #command_subparsers.required = True
    parser_verbose = parser.add_mutually_exclusive_group()
    parser_verbose.add_argument("-v", "--verbose", action="store_true", default=False, help="increase output verbosity")
    parser_verbose.add_argument('-q', '--quiet', action='store_true', default=False, help='do not write any output')
    #list
    list_parser=command_subparsers.add_parser('list', help='lists installed packages', prefix_chars='-+/')
    #list::output
    list_output = list_parser.add_mutually_exclusive_group()
    list_output.add_argument("-p", "--pipe", action="store_true", help='output a list of package in a format that can be piped')
    list_output.add_argument('-i', '--infos', action='store', nargs="+", help='infos to print in output among ',
                              choices=['name', 'author', 'installed', 'latest', 'state', 'url', 'install_type'],
                              default = ['name', 'author', 'installed', 'latest', 'state'])
    #list::state
    list_state = list_parser.add_mutually_exclusive_group()
    list_state.add_argument('-f', '--frozen', action='store_true', default=None, help='list frozen packages')
    list_state.add_argument('-r', '--rolling', action='store_true', default=None, help='list rolling packages')
    #list::uptodate
    list_uptodate = list_parser.add_mutually_exclusive_group()
    list_uptodate.add_argument('-u', '--uptodate', action="store_false", default=None, help='list non up-to-date packages')
    list_uptodate.add_argument('+u', '++uptodate', action="store_true", default=None, help='list up-to-date packages')
    #list::other
    list_parser.add_argument('-a', '--author', action='store', nargs=1, dest='author', default=None, help='list packages of author')

    #update
    update_parser=command_subparsers.add_parser('update', help='get the latest commited version of installed packages')
    #upgrade
    upgrade_parser=command_subparsers.add_parser('upgrade', help='upgrades the packages which are not up-to-date (providing they are not frozen)')
    upgrade_parser.add_argument('packages', metavar='repo', type=str, nargs='*', default=None, help='upgrade only selected packages')
    upgrade_parser.add_argument('-a', '--author', action='store', nargs=1, dest='author', default=None, help='upgrade packages of author')
    #freeze
    frozen_parser=command_subparsers.add_parser('freeze', help='prevents a package from being upgraded')
    frozen_parser.add_argument('packages', metavar='repo', type=str, nargs='*', default=None, help='package to freeze')
    frozen_parser.add_argument('-r','--rolling', action='store_true', default=None, help='freeze all rolling packages')
    frozen_parser.add_argument('-a','--author', action='store', nargs=1, dest='author', default=None, help='freeze packages of author')
    #roll
    rolling_parser=command_subparsers.add_parser('roll', help='allows a package to be upgraded again')
    rolling_parser.add_argument('packages', metavar='repo', type=str, nargs='*', default=None, help='package to roll')
    rolling_parser.add_argument('-f','--frozen', action='store_true', default=None, help='roll every frozen packages')
    rolling_parser.add_argument('-a','--author', action='store', nargs=1, dest='author', default=None, help='roll packages of author')
    #install
    install_parser=command_subparsers.add_parser('install', help='install selected package')
    install_parser.add_argument('packages', metavar='repo', type=str, nargs='+', help='package to install')
    install_parser.add_argument('--standalone', action='store_true', default=False, help='install all packages as standalone')
    #uninstall
    uninstall_parser=command_subparsers.add_parser('uninstall', help='uninstall selected package')
    uninstall_parser.add_argument('packages', metavar='repo', type=str, nargs='*', default=None, help='package to uninstall')
    uninstall_parser.add_argument('-a','--author', action='store', nargs=1, dest='author', default=None, help='uninstall packages of author')
    #info
    info_parser=command_subparsers.add_parser('info', help='grab infos about git-pm')
    info_parser.add_argument('-r', '--release', '--version', action='store_true', dest='release', default=False, help='print release version')
    info_parser.add_argument('-w', '--whereis', action='store_true', default=False, help='print localisation of script and config files')
    info_parser.add_argument('--poetry', action='store_true', default=[])
    #flush
    flush_parser=command_subparsers.add_parser('flush', help='deletes all files installed by git-pm (database, config files, logs, installed repositories, temporary directories)')
    
    options = vars(parser.parse_args(args))

    #add parsers to options dict for further referencement
    options['parser'] = {'main':parser, 'list':list_parser, 'upgrade':upgrade_parser,
                         'update':update_parser, 'freeze':frozen_parser,
                         'install':install_parser, 'roll':rolling_parser,
                         'uninstall':uninstall_parser, 'info':info_parser,
                         'flush':flush_parser}

    options.update(deep_convert_dict(confparse(args)))

    ##corrects dict
    ##Dicts may have missing entries depending on the command that was used
    for option in ('frozen', 'rolling', 'author', 'uptodate', 'release', 'whereis'):
        if not option in options.keys(): options[option]=None
    #package default does not work well
    if not 'packages' in options.keys() or not options['packages']: options['packages']=None
    #if no info option is passed: print all infos
    if options['cmd'] == 'info' and (True not in (options['release'], options['whereis'], options['poetry'])):
        options['whereis'], options['release'] = True, True
    ##checks for errors:
    if options['cmd'] is None:
        parser.print_help()
        parser.exit(2)
    #sudo ?
    if options['cmd']:
        if getpass.getuser() != 'root' and options['cmd'] not in ('info', 'list'):
            options['parser'][options['cmd']].error(red(bold('git-pm {} must be executed as root'.format(options['cmd']))))
    if not options['cmd'] in ('list', 'update', 'upgrade', 'info', 'flush'):
        if options['frozen'] is None and options['rolling'] is None and options['packages'] is None and options['author'] is None:
            options['parser'][options['cmd']].error('need packages to work on')

    return options
